summaryrefslogtreecommitdiffstats
path: root/libkdepim/progressmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/progressmanager.h')
-rw-r--r--libkdepim/progressmanager.h62
1 files changed, 32 insertions, 30 deletions
diff --git a/libkdepim/progressmanager.h b/libkdepim/progressmanager.h
index 47409002..745e69a2 100644
--- a/libkdepim/progressmanager.h
+++ b/libkdepim/progressmanager.h
@@ -36,9 +36,10 @@ class ProgressItem;
class ProgressManager;
typedef TQMap<ProgressItem*, bool> ProgressItemMap;
-class KDE_EXPORT ProgressItem : public QObject
+class KDE_EXPORT ProgressItem : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
friend class ProgressManager;
friend class TQDict< ProgressItem >; // so it can be deleted from dicts
@@ -51,9 +52,9 @@ class KDE_EXPORT ProgressItem : public QObject
const TQString& id() const { return mId; }
/**
* @return The parent item of this one, if there is one.
*/
- ProgressItem *parent() const { return mParent; }
+ ProgressItem *tqparent() const { return mParent; }
/**
* @return The user visible string to be used to represent this item.
@@ -69,13 +70,13 @@ class KDE_EXPORT ProgressItem : public QObject
/**
* @return The string to be used for showing this item's current status.
*/
- const TQString& status() const { return mStatus; }
+ const TQString& status() const { return mtqStatus; }
/**
* Set the string to be used for showing this item's current status.
* @p v will be interpreted as rich text, so it might have to be escaped.
* @param v The status string.
*/
- void seStatus( const TQString& v );
+ void setqStatus( const TQString& v );
/**
* @return Whether this item can be cancelled.
@@ -131,7 +132,7 @@ class KDE_EXPORT ProgressItem : public QObject
* Reset the progress value of this item to 0 and the status string to
* the empty string.
*/
- void reset() { setProgress( 0 ); seStatus( TQString::null ); mCompleted = 0; }
+ void reset() { setProgress( 0 ); setqStatus( TQString() ); mCompleted = 0; }
void cancel();
@@ -188,7 +189,7 @@ signals:
* @param The updated item.
* @param The new message.
*/
- void progressItemStatus( KPIM::ProgressItem*, const TQString& );
+ void progressItemtqStatus( KPIM::ProgressItem*, const TQString& );
/**
* Emitted when the label of an item changed. Should be used by
* progress dialogs to update the label of an item.
@@ -216,7 +217,7 @@ signals:
protected:
/* Only to be used by our good friend the ProgressManager */
- ProgressItem( ProgressItem* parent,
+ ProgressItem( ProgressItem* tqparent,
const TQString& id,
const TQString& label,
const TQString& status,
@@ -228,7 +229,7 @@ signals:
private:
TQString mId;
TQString mLabel;
- TQString mStatus;
+ TQString mtqStatus;
ProgressItem* mParent;
bool mCanBeCanceled;
unsigned int mProgress;
@@ -259,13 +260,14 @@ signals:
* one with that id, there will not be a new one created but the existing
* one will be returned. This is convenient for accessing items that are
* needed regularly without the to store a pointer to them or to add child
- * items to parents by id.
+ * items to tqparents by id.
*/
-class KDE_EXPORT ProgressManager : public QObject
+class KDE_EXPORT ProgressManager : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
virtual ~ProgressManager();
@@ -286,21 +288,21 @@ class KDE_EXPORT ProgressManager : public QObject
/**
* Creates a ProgressItem with a unique id and the given label.
* This is the simplest way to aquire a progress item. It will not
* have a parent and will be set to be cancellable and not using crypto.
*
* @param label The text to be displayed by progress handlers. It will be
* interpreted as rich text, so it might have to be escaped.
*/
static ProgressItem * createProgressItem( const TQString &label ) {
return instance()->createProgressItemImpl( 0, getUniqueID(), label,
- TQString::null, true, false );
+ TQString(), true, false );
}
/**
* Creates a new progressItem with the given parent, id, label and initial
* status.
*
* @param parent Specify an already existing item as the parent of this one.
* @param id Used to identify this operation for cancel and progress info.
* @param label The text to be displayed by progress handlers. It will be
* interpreted as rich text, so it might have to be escaped.
@@ -308,40 +310,40 @@ class KDE_EXPORT ProgressManager : public QObject
* interpreted as rich text, so it might have to be escaped.
* @param canBeCanceled can the user cancel this operation?
* @param usesCrypto does the operation use secure transports (SSL)
* Cancelling the parent will cancel the children as well (if they can be
* cancelled) and ongoing children prevent parents from finishing.
* @return The ProgressItem representing the operation.
*/
- static ProgressItem * createProgressItem( ProgressItem* parent,
+ static ProgressItem * createProgressItem( ProgressItem* tqparent,
const TQString& id,
const TQString& label,
- const TQString& status = TQString::null,
+ const TQString& status = TQString(),
bool canBeCanceled = true,
bool usesCrypto = false ) {
- return instance()->createProgressItemImpl( parent, id, label, status,
+ return instance()->createProgressItemImpl( tqparent, id, label, status,
canBeCanceled, usesCrypto );
}
/**
* Use this version if you have the id string of the parent and want to
* add a subjob to it.
*/
- static ProgressItem * createProgressItem( const TQString& parent,
+ static ProgressItem * createProgressItem( const TQString& tqparent,
const TQString& id,
const TQString& label,
- const TQString& status = TQString::null,
+ const TQString& status = TQString(),
bool canBeCanceled = true,
bool usesCrypto = false ) {
- return instance()->createProgressItemImpl( parent, id, label,
+ return instance()->createProgressItemImpl( tqparent, id, label,
status, canBeCanceled, usesCrypto );
}
/**
* Version without a parent.
*/
static ProgressItem * createProgressItem( const TQString& id,
const TQString& label,
- const TQString& status = TQString::null,
+ const TQString& status = TQString(),
bool canBeCanceled = true,
bool usesCrypto = false ) {
return instance()->createProgressItemImpl( 0, id, label, status,
@@ -380,8 +382,8 @@ class KDE_EXPORT ProgressManager : public QObject
void progressItemCompleted( KPIM::ProgressItem* );
/** @see ProgressItem::progressItemCanceled() */
void progressItemCanceled( KPIM::ProgressItem* );
- /** @see ProgressItem::progressItemStatus() */
- void progressItemStatus( KPIM::ProgressItem*, const TQString& );
+ /** @see ProgressItem::progressItemtqStatus() */
+ void progressItemtqStatus( KPIM::ProgressItem*, const TQString& );
/** @see ProgressItem::progressItemLabel() */
void progressItemLabel( KPIM::ProgressItem*, const TQString& );
/** @see ProgressItem::progressItemUsesCrypto() */
@@ -417,11 +419,11 @@ class KDE_EXPORT ProgressManager : public QObject
ProgressManager( const ProgressManager& );
virtual ProgressItem* createProgressItemImpl(
- ProgressItem* parent, const TQString& id,
+ ProgressItem* tqparent, const TQString& id,
const TQString& label, const TQString& status,
bool cancellable, bool usesCrypto );
virtual ProgressItem* createProgressItemImpl(
- const TQString& parent, const TQString& id,
+ const TQString& tqparent, const TQString& id,
const TQString& label, const TQString& status,
bool cancellable, bool usesCrypto );
void emitShowProgressDialogImpl();
@@ -51,9 +52,9 @@ class KDE_EXPORT ProgressItem : public QObject
const TQString& id() const { return mId; }
/**
- * @return The parent item of this one, if there is one.
+ * @return The tqparent item of this one, if there is one.
*/
@@ -286,21 +288,21 @@ class KDE_EXPORT ProgressManager : public QObject
* Creates a ProgressItem with a unique id and the given label.
* This is the simplest way to aquire a progress item. It will not
- * have a parent and will be set to be cancellable and not using crypto.
+ * have a tqparent and will be set to be cancellable and not using crypto.
*
* @param label The text to be displayed by progress handlers. It will be
@@ -286,21 +288,21 @@ class KDE_EXPORT ProgressManager : public QObject
}
/**
- * Creates a new progressItem with the given parent, id, label and initial
+ * Creates a new progressItem with the given tqparent, id, label and initial
* status.
*
@@ -286,21 +288,21 @@ class KDE_EXPORT ProgressManager : public QObject
* status.
*
- * @param parent Specify an already existing item as the parent of this one.
+ * @param tqparent Specify an already existing item as the tqparent of this one.
* @param id Used to identify this operation for cancel and progress info.
* @param label The text to be displayed by progress handlers. It will be
@@ -308,40 +310,40 @@ class KDE_EXPORT ProgressManager : public QObject
* @param canBeCanceled can the user cancel this operation?
* @param usesCrypto does the operation use secure transports (SSL)
- * Cancelling the parent will cancel the children as well (if they can be
- * cancelled) and ongoing children prevent parents from finishing.
+ * Cancelling the tqparent will cancel the tqchildren as well (if they can be
+ * cancelled) and ongoing tqchildren prevent tqparents from finishing.
* @return The ProgressItem representing the operation.
*/
@@ -308,40 +310,40 @@ class KDE_EXPORT ProgressManager : public QObject
}
/**
- * Use this version if you have the id string of the parent and want to
+ * Use this version if you have the id string of the tqparent and want to
* add a subjob to it.
*/
@@ -308,40 +310,40 @@ class KDE_EXPORT ProgressManager : public QObject
}
/**
- * Version without a parent.
+ * Version without a tqparent.
*/
static ProgressItem * createProgressItem( const TQString& id,